
/* Generated data (by glib-mkenums) */

#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
#error Only <epiphany/epiphany.h> can be included directly.
#endif

#ifndef EPHY_LIB_TYPE_BUILTINS_H
#define EPHY_LIB_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-node.h --- */
#define EPHY_TYPE_NODE_SIGNAL_TYPE ephy_node_signal_type_get_type()
GType ephy_node_signal_type_get_type (void);

/* --- ephy-state.h --- */
#define EPHY_TYPE_STATE_WINDOW_FLAGS ephy_state_window_flags_get_type()
GType ephy_state_window_flags_get_type (void);
G_END_DECLS

#endif /* EPHY_LIB_TYPE_BUILTINS_H */

/* Generated data ends here */

